'''
Definitions for the keys into the configuration file. Used with ConfigParser
object.

The key C{SECTION} identifies the replication section of the configuration, or
initialization, file. The other keys identify properties within the section.

The replication client uses the ESGCET config module for loading the ConfigParser
object. If no configuration file is provided on the command line, the default ESG
INI file is used. The ESG INI file will need to have a replication section, see
L{SECTION}, with replication-specific settings.

Created on Jul 15, 2010

@author: cward
@organization: USC Information Sciences Institute
'''
AUTH_SERV_KEY = 'hessian_service_authorization_url'
"""
The URL to the ESG authorization service.
@type: string
@deprecated: No longer used. The authorization policy of ESG changed making this
part of the Replication Client moot.
"""
AUTH_PORT_KEY = 'hessian_service_authorization_port'
"""
Port for the authorization service. 
@type: string
@deprecated: No longer used. The authorization policy of ESG changed making this
part of the Replication Client moot.
"""
AUTH_CERT_KEY = 'myproxy_certificate'
"""
Path to the certificate generated by the Globus myproxy-logon utility.
@type: string
"""
CHECKSUM_ALGORITHM = "checksum_algorithm"
"""
Set this to the value to use when checking the checksum elements for files in
the Gateway meta data. Default is "md5." Check is case insensitive.
@type: string 
"""
COMPARE_CHECKED = "replica_checked_properties"
"""
Comma separated list of properties that may be used to compare a replica TDS 
catalog with the originating catalog. A comparison only occurs when a listed
property is present in each of the DatasetExtract objects. See L{DatasetExtract}
for more details.
@type: string
"""
COMPARE_REQUIRED = "replica_required_properties"
"""
Comma separated list of properties to be required during a compare of a replica
TDS catalog with the originating catalog. The standard comparison only compares
two attributes if both extracts contain them. If one of the extract objects does
not contain a property in this list, the comparison will fail. See 
L{DatasetExtract} for more details.
@type: string
"""
DATA_ACCESS_MARKER = "data_access_marker"
"""
Name marker for selecting a data_access_capability element when a protocol has
more-than-one access point. For example, a GridFTP access point could use
standard Globus security mechanisms or ESG-(BDM-)specific security mechanisms.
The value of this setting will be used to match the "name" attribute of the
element.
@type: string
"""
DOWNLOAD_TYPE = "download_type"
"""
Controls the format of the data movement agent download request file. See
L{dataMovementRequest} for more details.
@type: string
"""
GUC_OPTIONS = "globus_guc_options"
"""
Assign this value to override the options passed to globus-url-copy when
generating a download request script for that tool. See L{dataMovementRequest}
for more information on data movement agents.
@type: string
@deprecated: This option is no longer needed because rather than recreate an
executable shell script for globus-url-copy, replication creates an input file
that is passed to globus-url-copy using the "-f" option.
"""
GOL_OPTIONS = "globus_online_options"
"""
Append this value to the C{source target} pairs when generating an input file
for use with the Globus Online file transfer service. See L{dataMovementRequest}
for more information on data movement agents.
@type: string
"""
HESSIAN_REMOTE_URL = "hessian_service_remote_metadata_url"
"""
The URL to the ESG gateway meta-data Hessian service. The meta-data service
provides the list of files that belong to a dataset as well as the location of
the TDS catalog at the originating data node.
@type: string
"""
HESSIAN_PORT = 'hessian_port'
"""
The port running the Hessian service on the gateway. (The program will
use 80 as a default if this value is not set.)
@type: string
"""
LOG_LEVEL = "log_level"
"""
Override the default logging level, C{ERROR}, with new setting. Should be a 
string from the Python C{logging} package:
 - CRITICAL
 - ERROR
 - WARNING
 - INFO
 - DEBUG
The C{CRITICAL} logging level is the least verbose. The C{DEBUG} will capture
all trace logging messages.
If the replication section of the configuration file does not contain a setting,
the configuration library looks in the C{DEFAULT} section. This will also
override the logging level.
@type: string
"""
REPLICA_ROOT = "replica_root"
"""
Prefix to the path for downloading dataset files. It may be relative to the
current directory or a fully qualified path. The default is the current
directory, which is almost certainly wrong.
@type: string
"""
SECTION = "replication"
"""
Section label with configuration keys for replication. If the section is not
present, the values may still be in the DEFAULT section.
@type: string 
"""
SKIP_COUNT = "skip_count"
"""
When processing the meta data query, number of directories to skip over in the
directory path of the original data publishing site. If the path were
"/foo/bar/baz" and skip were 2, then "/foo/bar" would be passed over before and
remaining path string appended to the value of "replica_root" for use as the
local directory path. If not set or 0, no directories will be skipped.
@note: This variable only effects processing for BDM, globus-url-copy, and
Globus Online options.
@type: integer 
"""
SOURCE_GTWY_KEY = "source_gateway"
"""
Key to retrieve the name for the ESG source gateway. This is the code for the
gateway server to publish datasets to. Acceptable values include C{ESG-PCMDI}
and C{ESG-NCAR}.
@note: The command line option C{--gateway} will override this setting.
@type: string
"""
TDS_TEMP_DIR_KEY = "tds_directory"
"""
The path to the TDS catalog file temporary storage. Temporary files include
a database mapping dataset IDs to source data node TDS catalog files and the
catalog files themselves.
@type: string
"""
