"""
Function to read the list of dataset IDs from the input file.
@note: It looks like this module was initially intended to be a general file I/O
library, but as the code developed, this did not happen. This simplified revision removes private
functions that were not used. (The remaining function is only used in
L{esgreplicate} so perhaps it could just be placed there as a private function
and this module removed from the package.)

@author: ebrady, cward
@organization: USC Information Sciences Institute
"""
import sys
import logging

_trace_log = logging.getLogger('app.' + __name__)
"""
@type: logging.Logger
"""
#------------------------------------------------------------------------------
#	get_dataset_listing
#	Accepts:	string input_file
#	Returns:	List of dataset ids
#------------------------------------------------------------------------------
def get_dataset_listing(input_file, config):
  """
  Read the dataset IDs from the input file into a list object.
  @param input_file: Path to file with dataset IDs.
  @type input_file: string
  @param config: Configuration data.
  @type config: ConfigParser
  @return: The dataset IDs as a list.
  @rtype: list
  """
  _trace_log.info("Entry: %s", input_file)
  list_of_dataset_ids = []
  try:
      dataset_file = open(input_file, "r")
      for line in dataset_file:
          if line[0] == '#':
              _trace_log.debug("Skipping line: %s", line)
              continue
          _trace_log.debug("Processing line: %s", line)
          datasetId = line.strip()
          if datasetId is not None:
             list_of_dataset_ids.append(datasetId);
      dataset_file.close()
  except EnvironmentError, e:
      _trace_log.exception("Error reading file of dataset IDs:")
      print >>sys.stderr, "Error reading file of dataset IDs:", str(e)
      
  _trace_log.debug("list_of_dataset_ids: %s", list_of_dataset_ids)

  if not list_of_dataset_ids:
    print >>sys.stderr, "No dataset IDs found in input file."

  _trace_log.info("Return: %s", list_of_dataset_ids)
  return list_of_dataset_ids
